body, input  { font-family: 'Lucida Grande', 'Lucida Sans Unicode', 'Geneva',
               'Verdana', sans-serif; background-color: #AFC1C4; color: #000;
               text-align: center; margin: 1em; padding: 0; font-size: 15px; }
input        { background-color: #fff; margin: 0; text-align: left; }
a            { color: #11557C; }
a:hover      { color: #177199; }
pre, code, table.source,
textarea     { font-family: 'Consolas', 'Deja Vu Sans Mono',
               'Bitstream Vera Sans Mono', monospace; font-size: 13px; }

div.debugger { text-align: left; padding: 12px; margin: auto;
               border: 1px solid #aaa; background-color: white; }
h1           { color: #11557C; font-size: 30px; margin: 0 0 0.3em 0; }
div.detail p { margin: 0 0 8px 13px; font-size: 14px; }
div.explanation { margin: 13px; font-size: 11px; }
div.footer   { background-color: #E3EFF1; font-size: 0.8em; text-align: right;
               padding: 6px 8px 6px 0; margin: 30px -12px -12px -12px;
               color: #86989B; }

h2           { font-size: 16px; margin: 1.3em 0 0.0 0; padding: 5px;
               background-color: #11557C; color: white; }
h2 em        { font-style: normal; color: #A5D6D9; font-weight: normal; }

div.traceback, div.plain { background-color: #eee!important; border: 1px solid #ccc;
                           margin: 0 0 1em 0; padding: 10px; }
div.plain p      { margin: 0; }
div.plain textarea,
div.plain pre { margin: 10px 0 0 0; padding: 4px; background-color: #333;
                border: 1px solid #111; color: white; }
div.plain textarea { width: 99%; height: 300px; }
div.traceback h3 { font-size: 1em; margin: 0 0 0.8em 0; }
div.traceback ul { list-style: none; margin: 0; padding: 0 0 0 1em; }
div.traceback h4 { font-size: 13px; font-weight: normal; margin: 0.7em 0 0.1em 0; }
div.traceback pre { margin: 0; padding: 5px 0 3px 15px;
                    background-color: #ccc; border-top: 1px solid #aaa;
                    border-left: 1px solid #aaa; border-right: 1px solid #fafafa;
                    border-bottom: 1px solid #fafafa; }
div.traceback pre,
div.box table.source { white-space: pre-wrap;       /* css-3 should we be so lucky... */
                       white-space: -moz-pre-wrap;  /* Mozilla, since 1999 */
                       white-space: -pre-wrap;      /* Opera 4-6 ?? */
                       white-space: -o-pre-wrap;    /* Opera 7 ?? */
                       word-wrap: break-word;       /* Internet Explorer 5.5+ */
                       _white-space: pre;           /* IE only hack to re-specify in
                                                    addition to word-wrap  */ }
div.traceback pre:hover { background-color: #fafafa; color: black; cursor: pointer; }
div.traceback blockquote { margin: 1em 0 0 0; padding: 0; }
div.traceback img { float: right; padding: 2px; margin: -3px 2px 0 0; display: none; }
div.traceback img:hover { background-color: #ddd; cursor: pointer; }
div.traceback pre:hover img { display: block; }

pre.console { background-color: #fafafa!important; color: black; padding: 5px!important;
              margin: 3px 0 0 0!important; cursor: default!important;
              max-height: 400px; overflow: auto; }
pre.console form { color: #555; }
pre.console input { background-color: #fafafa; color: #555;
                    width: 90%; font-family: 'Consolas', 'Deja Vu Sans Mono',
                    'Bitstream Vera Sans Mono', monospace; font-size: 13px;
                     border: none!important; }

span.string { color: #30799B; }
span.number { color: #9C1A1C; }
span.object { color: #485F6E; }
span.extended { opacity: 0.5; }
span.extended:hover { opacity: 1; }
a.toggle { text-decoration: none; background-repeat: no-repeat;
           background-position: center center;
           background-image: url(./__debugger__?cmd=resource&f=more.png); }
a.toggle:hover { background-color: #444; }
a.open { background-image: url(./__debugger__?cmd=resource&f=less.png); }

pre.console div.traceback { margin: 5px 0 5px 25px; white-space: normal; }
pre.console div.traceback h3 { background-color: #555; color: white;
                               margin: -10px -10px 5px -10px; padding: 5px; }
pre.console div.traceback pre:hover { background-color: #ccc; cursor: default; }

pre.console div.box { margin: 5px 0 5px 25px; white-space: normal;
                      border: 1px solid #ddd; }
pre.console div.box h3 { background-color: #555; color: white;
                         margin: 0; padding: 5px; }
pre.console div.box div.repr { padding: 8px; background-color: white; }
pre.console div.box table { margin-top: 6px; }
pre.console div.box pre.help { background-color: white; font-size: 12px; }
pre.console div.box pre.help:hover { cursor: default; }
pre.console table tr { vertical-align: top; }
div.box table.source { background-color: #fafafa; font-size: 12px;
                       border-collapse: collapse; width: 100%; }
div.box table.source td { border-top: 1px solid #eee; padding: 4px 0 4px 10px; }
div.box table.source td.lineno { color: #999; padding-right: 10px; width: 1px; }
div.box table.source tr.in-frame { background-color: #D6EEFF; }
div.box table.source tr.current { background-color: white; }
div.sourceview { max-height: 400px; overflow: auto; border: 1px solid #ccc; }
div.console { border: 1px solid #ccc; padding: 4px; background-color: #fafafa; }
